#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces

# import packages
from babel.core import Locale
from babel.numbers import format_decimal
from pyams_utils.request import check_request

from pyams_utils import _


def get_human_size(value, request=None):
    """Convert given bytes value in human readable format

    >>> from pyramid.testing import DummyRequest
    >>> request = DummyRequest(params={'_LOCALE_': 'fr'})
    >>> request.locale_name
    'fr'

    >>> from pyams_utils.size import get_human_size
    >>> get_human_size(256, request)
    '256 bytes'
    >>> get_human_size(3678, request)
    '3,6 Kb'
    >>> get_human_size(6785342, request)
    '6,47 Mb'
    >>> get_human_size(3674815342, request)
    '3,422 Gb'
    """
    if request is None:
        request = check_request()
    translate = request.localizer.translate
    locale = Locale(request.locale_name)
    if value < 1024:
        return format_decimal(value, translate(_('0 bytes')), locale)
    value /= 1024
    if value < 1024:
        return format_decimal(value, translate(_('0.# Kb')), locale)
    value /= 1024
    if value < 1024:
        return format_decimal(value, translate(_('0.0# Mb')), locale)
    value /= 1024
    return format_decimal(value, translate(_('0.0## Gb')), locale)
